macro_rules! loop_try { ( $($body_parts:tt)* ) => { ... }; }
A loop that caches errors and retries with exponential backoff. (Backoff parameters and error messaging hard coded for now, as is anyhow::Result.)