or_return_none

Macro or_return_none 

macro_rules! or_return_none {
    ($e:expr) => { ... };
}
Similar to ? in a context that returns Option, this propagates None values, but wraps them in Ok. I.e. behaves like ? except if the Option context is wrapped in a Result.