pub struct MarkdownMeta { /* private fields */ }Implementations
Sourceimpl MarkdownMeta
impl MarkdownMeta
pub fn toc_html_fragment(&self, html: &HtmlAllocator) -> Result<AId<Node>>
pub fn footnotes_html_fragment( &self, html: &HtmlAllocator, style: &dyn StylingInterface, ) -> Result<(usize, AId<Node>), MarkdownFileError>
Sourcepub fn title_and_remaining_headings(
&self,
) -> (Option<&ASlice<Node>>, &Vec<MarkdownHeading>, bool)
pub fn title_and_remaining_headings( &self, ) -> (Option<&ASlice<Node>>, &Vec<MarkdownHeading>, bool)
Split title/header hierarchy into title and rest; takes
<title> if available by preference, otherwise the first
heading if it’s a ‘#’ and there are no other ‘#’ ones. The
last returned value is true if a heading from the markdown
file was skipped (i.e. it needs to be dropped from the
generated HTML to avoid header duplication).
Sourcepub fn title(&self) -> Option<&ASlice<Node>>
pub fn title(&self) -> Option<&ASlice<Node>>
The contents of an optional single <title> element,
or if missing, the first heading if it’s a
‘#’ and there are no other ‘#’ ones.
Sourcepub fn title_string(
&self,
html: &HtmlAllocator,
alternative: &str,
) -> Result<KString>
pub fn title_string( &self, html: &HtmlAllocator, alternative: &str, ) -> Result<KString>
Like title but as a string with markup stripped, and falling
back to alternative if not present.