Takes a place (variable or field) holding an Option<T> and an
expression that returns T; returns a &T to the value held by
the Option, runs the expression and stores the result in the
place if it holds None. The name is from what the // operator
in Perl (theres also //=which this is really) is called. The expression is executed in the context of theoerrcall, with no additional subroutine wrapper, meaning e.g.?jumps out of theoerr` (it is designed like this on purpose).
Similar to ? in a context that returns Option, this propagates
None values, but wraps them in Ok. I.e. behaves like ?
except if the Option context is wrapped in a Result.